summaryrefslogtreecommitdiff
path: root/bin/check-missing-unittests.py
diff options
context:
space:
mode:
Diffstat (limited to 'bin/check-missing-unittests.py')
-rwxr-xr-xbin/check-missing-unittests.py5
1 files changed, 3 insertions, 2 deletions
diff --git a/bin/check-missing-unittests.py b/bin/check-missing-unittests.py
index 33a6e36d67c1..b685d00993bf 100755
--- a/bin/check-missing-unittests.py
+++ b/bin/check-missing-unittests.py
@@ -188,8 +188,9 @@ def main(ignoredBugs):
priority = bug['priority']
break
- #Ignore open bugs and performance bugs
- if status and not isOpen(status) and 'perf' not in keywords:
+ #Ignore open bugs, performance bugs and accessibility bugs
+ if status and not isOpen(status) and 'perf' not in keywords \
+ and 'accessibility' not in keywords:
print(
"# {} - [{}] {} - [https://bugs.documentfoundation.org/show_bug.cgi?id={} tdf#{}]".format(
info[0], priority.upper(), info[1], bugId, bugId))